-- ----------------------------------------------------------------------- 
-- OAuthToken 
-- ----------------------------------------------------------------------- 

DROP TABLE OAuthToken CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Param 
-- ----------------------------------------------------------------------- 

DROP TABLE Param CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Feature 
-- ----------------------------------------------------------------------- 

DROP TABLE Feature CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- SharedData 
-- ----------------------------------------------------------------------- 

DROP TABLE SharedData CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Preference 
-- ----------------------------------------------------------------------- 

DROP TABLE Preference CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Participant 
-- ----------------------------------------------------------------------- 

DROP TABLE Participant CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- PreferenceDefault 
-- ----------------------------------------------------------------------- 

DROP TABLE PreferenceDefault CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- WidgetInstance 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetInstance CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- StartFile 
-- ----------------------------------------------------------------------- 

DROP TABLE StartFile CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Description 
-- ----------------------------------------------------------------------- 

DROP TABLE Description CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Author 
-- ----------------------------------------------------------------------- 

DROP TABLE Author CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Name 
-- ----------------------------------------------------------------------- 

DROP TABLE Name CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- License 
-- ----------------------------------------------------------------------- 

DROP TABLE License CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- WidgetIcon 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetIcon CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- Widget 
-- ----------------------------------------------------------------------- 

DROP TABLE Widget CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- OPENJPA_SEQUENCE_TABLE 
-- ----------------------------------------------------------------------- 

DROP TABLE OPENJPA_SEQUENCE_TABLE CASCADE CONSTRAINTS;

-- ----------------------------------------------------------------------- 
-- OPENJPA_SEQUENCE_TABLE 
-- ----------------------------------------------------------------------- 

CREATE TABLE OPENJPA_SEQUENCE_TABLE
(
    ID NUMBER(3) NOT NULL,
    SEQUENCE_VALUE NUMBER(38),
    PRIMARY KEY (ID)
);

-- ----------------------------------------------------------------------- 
-- Widget 
-- ----------------------------------------------------------------------- 

CREATE TABLE Widget
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    package_path VARCHAR2(255),
    default_locale VARCHAR2(255),
    height INTEGER,
    width INTEGER,
    guid VARCHAR2(255) NOT NULL,
    update_location CLOB,
    widget_version VARCHAR2(255),
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX UNWidget1 ON Widget (guid);

-- ----------------------------------------------------------------------- 
-- WidgetIcon 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetIcon
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    src CLOB,
    height INTEGER,
    width INTEGER,
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetIcon1 ON WidgetIcon (widget_id);

-- ----------------------------------------------------------------------- 
-- License 
-- ----------------------------------------------------------------------- 

CREATE TABLE License
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    href CLOB,
    text CLOB,
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXLicense1 ON License (widget_id);

-- ----------------------------------------------------------------------- 
-- Name 
-- ----------------------------------------------------------------------- 

CREATE TABLE Name
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    name CLOB,
    shortName VARCHAR2(255),
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXName1 ON Name (widget_id);

-- ----------------------------------------------------------------------- 
-- Author 
-- ----------------------------------------------------------------------- 

CREATE TABLE Author
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    author CLOB,
    email CLOB,
    href CLOB,
    lang VARCHAR2(255),
    dir VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXAuthor1 ON Author (widget_id);

-- ----------------------------------------------------------------------- 
-- Description 
-- ----------------------------------------------------------------------- 

CREATE TABLE Description
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    content CLOB,
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXDescription1 ON Description (widget_id);

-- ----------------------------------------------------------------------- 
-- StartFile 
-- ----------------------------------------------------------------------- 

CREATE TABLE StartFile
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    url CLOB,
    charset VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXStartFile1 ON StartFile (widget_id);

-- ----------------------------------------------------------------------- 
-- WidgetInstance 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetInstance
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    apikey VARCHAR2(255) NOT NULL,
    userId VARCHAR2(255) NOT NULL,
    sharedDataKey VARCHAR2(255),
    nonce VARCHAR2(255),
    idKey VARCHAR2(255) NOT NULL,
    opensocialToken CLOB NOT NULL,
    widget_id INTEGER NOT NULL,
    updated CHAR(1),
    shown CHAR(1),
    hidden CHAR(1),
    locked CHAR(1),
    lang VARCHAR2(255),
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetInstance1 ON WidgetInstance (widget_id);

CREATE UNIQUE INDEX UNWidgetInstance1 ON WidgetInstance (idKey);

-- ----------------------------------------------------------------------- 
-- PreferenceDefault 
-- ----------------------------------------------------------------------- 

CREATE TABLE PreferenceDefault
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_id INTEGER,
    preference VARCHAR2(255) NOT NULL,
    value VARCHAR2(1024) NOT NULL,
    readOnly CHAR(1),
    PRIMARY KEY (id)
);

CREATE INDEX IXPreferenceDefault1 ON PreferenceDefault (widget_id);

-- ----------------------------------------------------------------------- 
-- Participant 
-- ----------------------------------------------------------------------- 

CREATE TABLE Participant
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    participant_id VARCHAR2(255) NOT NULL,
    participant_display_name VARCHAR2(255) NOT NULL,
    participant_thumbnail_url VARCHAR2(1024),
    sharedDataKey VARCHAR2(255) NOT NULL,
    role VARCHAR2(255),
    PRIMARY KEY (id)
);

-- ----------------------------------------------------------------------- 
-- Preference 
-- ----------------------------------------------------------------------- 

CREATE TABLE Preference
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_instance_id INTEGER,
    dkey VARCHAR2(255),
    dvalue CLOB,
    readOnly CHAR(1),
    PRIMARY KEY (id)
);

CREATE INDEX IXPreference1 ON Preference (widget_instance_id);

CREATE UNIQUE INDEX UNPreference1 ON Preference (widget_instance_id, dkey);

-- ----------------------------------------------------------------------- 
-- SharedData 
-- ----------------------------------------------------------------------- 

CREATE TABLE SharedData
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    sharedDataKey VARCHAR2(255),
    dkey VARCHAR2(255),
    dvalue CLOB,
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXSharedData1 ON SharedData (widget_id);

-- ----------------------------------------------------------------------- 
-- Feature 
-- ----------------------------------------------------------------------- 

CREATE TABLE Feature
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    featureName VARCHAR2(255) NOT NULL,
    required CHAR(1),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXFeature1 ON Feature (widget_id);

-- ----------------------------------------------------------------------- 
-- Param 
-- ----------------------------------------------------------------------- 

CREATE TABLE Param
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    feature_id INTEGER,
    parameterName VARCHAR2(255) NOT NULL,
    parameterValue VARCHAR2(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXParam1 ON Param (feature_id);

-- ----------------------------------------------------------------------- 
-- OAuthToken 
-- ----------------------------------------------------------------------- 

CREATE TABLE OAuthToken
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    authzUrl VARCHAR2(255) NOT NULL,
    accessToken VARCHAR2(255) NOT NULL,
    clientId VARCHAR2(255) NOT NULL,
    expires NUMBER(38) NOT NULL,
    widget_instance_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXOAuthToken1 ON OAuthToken (widget_instance_id);

ALTER TABLE WidgetIcon
    ADD CONSTRAINT FKWidgetIcon1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE License
    ADD CONSTRAINT FKLicense1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Name
    ADD CONSTRAINT FKName1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Author
    ADD CONSTRAINT FKAuthor1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Description
    ADD CONSTRAINT FKDescription1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE StartFile
    ADD CONSTRAINT FKStartFile1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE WidgetInstance
    ADD CONSTRAINT FKWidgetInstance1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE PreferenceDefault
    ADD CONSTRAINT FKPreferenceDefault1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Preference
    ADD CONSTRAINT FKPreference1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

ALTER TABLE SharedData
    ADD CONSTRAINT FKSharedData1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Feature
    ADD CONSTRAINT FKFeature1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Param
    ADD CONSTRAINT FKParam1 FOREIGN KEY (feature_id) REFERENCES Feature (id);

ALTER TABLE OAuthToken
    ADD CONSTRAINT FKOAuthToken1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

